# BulkTokenRevoke

parameters used to constrain which tokens can be bulk revoked
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_id** | **str** | The unique id of the User from which to revoke tokens  | 
**org_id** | **str** | The unique id of the Organisation from which to revoke tokens  | [optional] 
**session_id** | **str** | The unique id of the session from which to revoke tokens  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


